@@ -312,11 +312,6 @@ class MyForm(QtGui.QMainWindow):
 		if len(station)>0:
 			if self.p.last == "stations":
 				self.p.pandora.stdin.write("\n")
-			elif self.p.last == "song":
-				self.p.pandora.stdin.write(self.c.act_stationchange)
-				self.p.pandora.stdin.write("\n")
-				self.ui.btnPlay.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
-				self.p.playing = 0
 
 			self.p.pandora.stdin.write(self.c.act_stationcreate)
 			self.p.pandora.stdin.write(station+"\n")
@@ -355,6 +350,9 @@ class MyForm(QtGui.QMainWindow):
 		if self.p.last == 'create':
 			self.p.pandora.stdin.write(str(self.ui.listStations.currentIndex())+"\n")
 			QtGui.QMessageBox.warning(self, 'Station Created', 'Your station has been created.')
+			f = open(os.path.expanduser("~")+'/.config/pianobar/lastplayed', 'w')
+			f.write(self.ui.listStations.currentText())
+			f.close()
 			self.p.pandora.stdin.write(self.c.act_stationchange)
 		else:
 			if self.p.last == "song":
